==> react-lds-8.7.0.tgz: package/es/components/MediaObject/MediaObject.js <==
import "core-js/modules/es6.object.assign";
import "core-js/modules/es6.array.iterator";
import "core-js/modules/es6.object.keys";
import "core-js/modules/es6.string.iterator";
import "core-js/modules/es6.array.from";
import "core-js/modules/es6.regexp.to-string";
import "core-js/modules/es6.object.to-string";
import "core-js/modules/es7.symbol.async-iterator";
import "core-js/modules/es6.symbol";
import "core-js/modules/web.dom.iterable";

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

function _toConsumableArray(arr) { return _arrayWithoutHoles(arr) || _iterableToArray(arr) || _nonIterableSpread(); }

function _nonIterableSpread() { throw new TypeError("Invalid attempt to spread non-iterable instance"); }

function _iterableToArray(iter) { if (Symbol.iterator in Object(iter) || Object.prototype.toString.call(iter) === "[object Arguments]") return Array.from(iter); }

function _arrayWithoutHoles(arr) { if (Array.isArray(arr)) { for (var i = 0, arr2 = new Array(arr.length); i < arr.length; i++) { arr2[i] = arr[i]; } return arr2; } }

import React from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';

var renderFigure = function renderFigure(figure, classes) {
  return React.createElement("div", {
    className: cx.apply(void 0, _toConsumableArray(classes))
  }, figure);
};

var MediaObject = function MediaObject(props) {
  var bodyClassName = props.bodyClassName,
      center = props.center,
      children = props.children,
      className = props.className,
      customTag = props.customTag,
      figureLeft = props.figureLeft,
      figureRight = props.figureRight,
      renderFigureLeft = props.renderFigureLeft,
      renderFigureRight = props.renderFigureRight,
      responsive = props.responsive,
      size = props.size,
      title = props.title,
      truncate = props.truncate,
      rest = _objectWithoutProperties(props, ["bodyClassName", "center", "children", "className", "customTag", "figureLeft", "figureRight", "renderFigureLeft", "renderFigureRight", "responsive", "size", "title", "truncate"]);

  var Tag = customTag || 'div';
  var figureLeftRenderer = renderFigureLeft || renderFigure;
  var figureRightRenderer = renderFigureRight || renderFigure;
  return React.createElement(Tag, _extends({}, rest, {
    className: cx('slds-media', {
      'slds-media_center': center
    }, {
      'slds-media_responsive': responsive
    }, _defineProperty({}, "slds-media_".concat(size), !!size), className)
  }), figureLeft && figureLeftRenderer(figureLeft, ['slds-media__figure']), React.createElement("div", {
    className: cx('slds-media__body', {
      'slds-truncate': truncate
    }, bodyClassName),
    title: title
  }, children), figureRight && figureRightRenderer(figureRight, ['slds-media__figure', 'slds-media__figure_reverse']));
};

MediaObject.defaultProps = {
  bodyClassName: null,
  center: true,
  children: null,
  className: null,
  customTag: null,
  figureLeft: null,
  figureRight: null,
  renderFigureLeft: null,
  renderFigureRight: null,
  responsive: false,
  size: null,
  truncate: false,
  title: null
};
MediaObject.propTypes = process.env.NODE_ENV !== "production" ? {
  /**
   * Optional class name which is appended to the body div
   */
  bodyClassName: PropTypes.string,

  /**
   * horizontally centers figures with content
   */
  center: PropTypes.bool,

  /**
   * mediaObject content
   */
  children: PropTypes.node,

  /**
   * Renders a customTag instead of a div
   */
  customTag: PropTypes.string,

  /**
   * class name
   */
  className: PropTypes.string,

  /**
   * sets a figure on the left side of the media object
   */
  figureLeft: PropTypes.node,

  /**
   * sets a figure on the right side of the media object
   */
  figureRight: PropTypes.node,

  /**
   * Function to render figureLeft. Receives (elem, classes) as arguments
   */
  renderFigureLeft: PropTypes.func,

  /**
   * Function to render figureRight. Receives (elem, classes) as arguments
   */
  renderFigureRight: PropTypes.func,

  /**
   * renders a responsive variant of the MediaObject
   */
  responsive: PropTypes.bool,

  /**
   * Sizes: small, large
   */
  size: PropTypes.oneOf(['small', 'large']),

  /**
   * truncates the body, requires title
   */
  truncate: PropTypes.bool,

  /**
   * title is necessary if truncate is used
   */
  title: PropTypes.string
} : {};
export default MediaObject;

==> react-lds-9.1.0.tgz: package/es/components/MediaObject/MediaObject.js <==
import "core-js/modules/es.symbol";
import "core-js/modules/es.symbol.description";
import "core-js/modules/es.symbol.iterator";
import "core-js/modules/es.array.from";
import "core-js/modules/es.array.index-of";
import "core-js/modules/es.array.iterator";
import "core-js/modules/es.date.to-string";
import "core-js/modules/es.object.assign";
import "core-js/modules/es.object.keys";
import "core-js/modules/es.object.to-string";
import "core-js/modules/es.regexp.to-string";
import "core-js/modules/es.string.iterator";
import "core-js/modules/web.dom-collections.iterator";

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

function _toConsumableArray(arr) { return _arrayWithoutHoles(arr) || _iterableToArray(arr) || _nonIterableSpread(); }

function _nonIterableSpread() { throw new TypeError("Invalid attempt to spread non-iterable instance"); }

function _iterableToArray(iter) { if (Symbol.iterator in Object(iter) || Object.prototype.toString.call(iter) === "[object Arguments]") return Array.from(iter); }

function _arrayWithoutHoles(arr) { if (Array.isArray(arr)) { for (var i = 0, arr2 = new Array(arr.length); i < arr.length; i++) { arr2[i] = arr[i]; } return arr2; } }

import React from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';

var renderFigure = function renderFigure(figure, classes) {
  return React.createElement("div", {
    className: cx.apply(void 0, _toConsumableArray(classes))
  }, figure);
};

var MediaObject = function MediaObject(props) {
  var as = props.as,
      bodyClassName = props.bodyClassName,
      center = props.center,
      children = props.children,
      className = props.className,
      customTag = props.customTag,
      figureLeft = props.figureLeft,
      figureRight = props.figureRight,
      renderFigureLeft = props.renderFigureLeft,
      renderFigureRight = props.renderFigureRight,
      responsive = props.responsive,
      size = props.size,
      title = props.title,
      truncate = props.truncate,
      rest = _objectWithoutProperties(props, ["as", "bodyClassName", "center", "children", "className", "customTag", "figureLeft", "figureRight", "renderFigureLeft", "renderFigureRight", "responsive", "size", "title", "truncate"]);

  var Tag = as || customTag || 'div';
  var figureLeftRenderer = renderFigureLeft || renderFigure;
  var figureRightRenderer = renderFigureRight || renderFigure;
  return React.createElement(Tag, _extends({}, rest, {
    className: cx('slds-media', {
      'slds-media_center': center
    }, {
      'slds-media_responsive': responsive
    }, _defineProperty({}, "slds-media_".concat(size), !!size), className)
  }), figureLeft && figureLeftRenderer(figureLeft, ['slds-media__figure']), React.createElement("div", {
    className: cx('slds-media__body', {
      'slds-truncate': truncate
    }, bodyClassName),
    title: title
  }, children), figureRight && figureRightRenderer(figureRight, ['slds-media__figure', 'slds-media__figure_reverse']));
};

MediaObject.defaultProps = {
  as: null,
  bodyClassName: null,
  center: true,
  children: null,
  className: null,
  customTag: null,
  figureLeft: null,
  figureRight: null,
  renderFigureLeft: null,
  renderFigureRight: null,
  responsive: false,
  size: null,
  truncate: false,
  title: null
};
MediaObject.propTypes = process.env.NODE_ENV !== "production" ? {
  /**
   * Renders a custom tag instead of a div
   */
  as: PropTypes.string,

  /**
   * Optional class name which is appended to the body div
   */
  bodyClassName: PropTypes.string,

  /**
   * horizontally centers figures with content
   */
  center: PropTypes.bool,

  /**
   * mediaObject content
   */
  children: PropTypes.node,

  /**
   * [DEPRECATED] Renders a customTag instead of a div
   */
  customTag: PropTypes.string,

  /**
   * class name
   */
  className: PropTypes.string,

  /**
   * sets a figure on the left side of the media object
   */
  figureLeft: PropTypes.node,

  /**
   * sets a figure on the right side of the media object
   */
  figureRight: PropTypes.node,

  /**
   * Function to render figureLeft. Receives (elem, classes) as arguments
   */
  renderFigureLeft: PropTypes.func,

  /**
   * Function to render figureRight. Receives (elem, classes) as arguments
   */
  renderFigureRight: PropTypes.func,

  /**
   * renders a responsive variant of the MediaObject
   */
  responsive: PropTypes.bool,

  /**
   * Sizes: small, large
   */
  size: PropTypes.oneOf(['small', 'large']),

  /**
   * truncates the body, requires title
   */
  truncate: PropTypes.bool,

  /**
   * title is necessary if truncate is used
   */
  title: PropTypes.string
} : {};
export default MediaObject;
